# MiceCraft

MiceCraft is designed to create, monitor and control smart habitats for animals.

> [!TIP]
> Public release coming fall 2025.

> [!CAUTION]
> This MiceCraft repository is the public version and will get progressive updates from the private closed-beta repository

## Install package

```
pip install micecraft
```

## Website

[https://micecraft.org](https://micecraft.org)

## Wiki and docs:

[MiceCraft Wiki](https://github.com/fdechaumont/micecraft/wiki)

## Github

[MiceCraft GitHub](https://github.org/micecraft)

## Main versions

Version  | Change | Date
------------- | ------------- | -------------
0.0.1  | Setting up :tada: | September 2025
0.0.5 | Added: FED3 Device <br> Added: ComManager <br> Added: DeviceEvent <br> Added: Alarm <br> Added: Mail | September 2025
0.0.6 | Added: CameraRecorder & associated example + wiki | September 2025
0.0.7 | Added: Lever | September 2025
0.0.8 | Added: <br>A lot of documentation (in the wiki)<br>Gate <br>Events <br>Report <br>First examples <br>Network <br>RFID reader| September 2025



